/* Interface so we can either use MySQL or flat files */

import java.util.List;
import java.util.Map;
import net.minecraft.server.MinecraftServer;

public abstract class DataSource {
    protected List<User> users;
    protected List<Group> groups;
    protected List<Kit> kits;
    protected Map<String, Location> homes;
    protected Map<String, Location> warps;

    abstract public void initialize(MinecraftServer server);

    public void reload() {
        loadUsers();
        loadGroups();
        loadKits();
        loadHomes();
        loadWarps();
    }

    abstract public void loadUsers();
    abstract public void loadGroups();
    abstract public void loadKits();
    abstract public void loadHomes();
    abstract public void loadWarps();

    abstract public void addUser(User user);
    abstract public void modifyUser(User user);

    public User getUser(String name) {
        for (User user : users)
            if (user.Name.equalsIgnoreCase(name))
                return user;
        return null;
    }

    abstract public void addGroup(Group group);
    abstract public void modifyGroup(Group group);

    public Group getGroup(String name) {
        for (Group group : groups)
            if (group.Name.equalsIgnoreCase(name))
                return group;
        return null;
    }

    abstract public void addKit(Kit kit);
    abstract public void modifyKit(Kit kit);

    public Kit getKit(String name) {
        for (Kit kit : kits)
            if (kit.Name.equalsIgnoreCase(name))
                return kit;
        return null;
    }

    abstract public void addHome(String name, Location location);
    abstract public void changeHome(String name, Location location);

    public Location getHome(String name) {
        if (homes.containsKey(name))
            return homes.get(name);
        return null;
    }

    abstract public void addWarp(String name, Location location);
    abstract public void changeWarp(String name, Location location);

    public Location getWarp(String name) {
        if (warps.containsKey(name))
            return warps.get(name);
        return null;
    }
}
